/***********************************************************
 * $Id$
 * 
 * Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 28.03.2007
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 * 
 ***********************************************************/

package org.clazzes.util.sec;

import java.util.Collection;
import java.util.TreeMap;

/**
 * @author lech
 *
 * This factory creates password hashers.
 */
public class HasherFactory implements PasswordHasherFactory {

    public TreeMap<String, PasswordHasher> hashers_byname;

    /**
     * 
     */
    public HasherFactory() {
      checkHashers();
    }

    /**
     * Creates the hasher cache. 
     */
    private synchronized void checkHashers()
    {
        if (this.hashers_byname != null)
            return;
        this.hashers_byname = new TreeMap<String, PasswordHasher>();
        PasswordHasher plain_hasher = new PlainPasswordHasher();
        this.hashers_byname.put(plain_hasher.getAlgorithmName().toUpperCase(), plain_hasher);
        SSHA1PasswordHasher sha1_hasher = new SSHA1PasswordHasher();
        this.hashers_byname.put(sha1_hasher.getAlgorithmName().toUpperCase(), sha1_hasher);
        CryptPasswordHasher crypt_hasher = new CryptPasswordHasher();
        this.hashers_byname.put(crypt_hasher.getAlgorithmName().toUpperCase(), crypt_hasher);
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.sec.PasswordHasherFactory#getPasswordHasher(java.lang.String)
     */
    public PasswordHasher getPasswordHasher(String algo_name)
    {
        //checkHashers();
        if (algo_name==null)
          return null;
        PasswordHasher hasher = this.hashers_byname.get(algo_name.toUpperCase());
        return hasher;
    }
    
    /* (non-Javadoc)
     * @see org.clazzes.util.sec.PasswordHasherFactory#getKnownPasswordHashers()
     */
    public Collection<PasswordHasher> getKnownPasswordHashers() {
        // checkHashers();
        return this.hashers_byname.values();
    }


}
