/***********************************************************
 * $Id: FieldAccessor.java 4 2006-12-26 19:16:57Z wglas $
 * 
 * Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 2006-03-13
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 * 
 ***********************************************************/

package org.clazzes.util.sec;

/**
 * The password hasher interface, to allow maximum flexibility
 */
public interface PasswordHasher
{

	/**
     * Hashes the given password using a random salt.
	 * @param cleartext Password to hash.
	 * @return the hashed i.e. encrypted password. includes the algorithm prefix.
	 */
	public String hashPassword(String cleartext);

	/**
     * Hashes the given password using the given salt.
     * @param cleartext Password to hash.
     * @param salt the salt to use.
     * @return the hashed i.e. encrypted password. includes the algorithm prefix.
	 */
	public String hashPassword(String cleartext, String salt);

	/**
     * Checks if the given cleartext password conforms to the given hashed representation.
	 * @param cleartext cleartext password to check.
	 * @param hashed hashed correct password to check against. may include the algorithm prefix.
	 * @return true if the password seems correct.
	 */
	public boolean checkPassword(String cleartext, String hashed);

	/**
	 * @return the name (key) of the algorithm implemented by this hasher, as used in the algorithm prefix of hashed passwords.
	 */
	public String getAlgorithmName();
    
    
    /**
     * @return the (default resp. relevant) salt length for the hash algorithm
     */
    public int getSaltLength();

}
