/***********************************************************
 * $Id: ThreadStopper.java 12 2007-01-18 10:28:04Z wglas $
 * 
 * Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 2006-12-27
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 * 
 ***********************************************************/

package org.clazzes.util.thread;

/**
 * @author wglas
 * 
 * this class is used in threads, which periodically check for an external
 * request for terminating it's work.
 */
public class ThreadStopper {
    /**
     * This variable is set to true, if the thread has been requested to finish.
     */
    boolean toBeFinished;

    /**
     * Instantiates a new ThreadStopper instance, which is in the
     * not-being-stopped state.
     */
    public ThreadStopper() {
        super();
        this.toBeFinished = false;
    }

    /**
     * This method is used inside the thread's main loop in order to check,
     * whether the thread has be stopped the next time it has finished a portion
     * of his work.
     * 
     * @return true, if we should leave the thread loop now.
     */
    public synchronized boolean isToBeFinished() {
        return this.toBeFinished;
    }

    /**
     * This function waits up to the given timeout in milliseconds or exits
     * immediately after requestStop() has been called. In the later case, the
     * function returns true.
     * 
     * @param timeout
     *            The maximal number of milliseconds to wait.
     * @return true, if the main loop should be left immediately.
     * @throws InterruptedException
     *             if some other thread calls Thread.interrupt on this Thread
     *             while waiting.
     */
    public synchronized boolean waitToBeFinished(long timeout)
            throws InterruptedException {
        if (!this.toBeFinished)
            this.wait(timeout);

        return this.toBeFinished;
    }

    public synchronized void waitToBeFinished() throws InterruptedException {
        this.wait();
    }

    /**
     * Requests the thread to be stopped. Since the thread may just be doing
     * some work, it may take some time until the thread really stops.
     */
    public synchronized void requestStop() {
        this.toBeFinished = true;
        this.notifyAll();
    }

    /**
     * Requests the thread to be stopped. Since the thread may just be doing
     * some work, it may take some time until the thread really stops.
     */
    public synchronized void resume() {
        this.notifyAll();
    }
}
